==> payara-embedded-all-4.1.1.171-sources.jar: fish/payara/notification/xmpp/XmppNotifierConfigurationExecutionOptionsFactory.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2016 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.notification.xmpp;

import fish.payara.nucleus.notification.configuration.NotifierType;
import fish.payara.nucleus.notification.domain.NotifierConfigurationExecutionOptionsFactory;
import org.glassfish.api.StartupRunLevel;
import org.glassfish.hk2.runlevel.RunLevel;
import org.jvnet.hk2.annotations.Service;

import javax.annotation.PostConstruct;
import java.io.UnsupportedEncodingException;

/**
 * @author mertcaliskan
 */
@Service
@RunLevel(StartupRunLevel.VAL)
public class XmppNotifierConfigurationExecutionOptionsFactory
        extends NotifierConfigurationExecutionOptionsFactory<XmppNotifierConfiguration, XmppNotifierConfigurationExecutionOptions> {

    @PostConstruct
    void postConstruct() {
        registerExecutionOptions(NotifierType.XMPP, this);
    }

    @Override
    public XmppNotifierConfigurationExecutionOptions build(XmppNotifierConfiguration notifierConfiguration) throws UnsupportedEncodingException {
        XmppNotifierConfigurationExecutionOptions executionOptions = new XmppNotifierConfigurationExecutionOptions();
        executionOptions.setEnabled(Boolean.parseBoolean(notifierConfiguration.getEnabled()));

        executionOptions.setHost(notifierConfiguration.getHost());
        executionOptions.setPort(notifierConfiguration.getPort());
        executionOptions.setServiceName(notifierConfiguration.getServiceName());
        executionOptions.setUsername(notifierConfiguration.getUsername());
        executionOptions.setPassword(notifierConfiguration.getPassword());
        executionOptions.setSecurityDisabled(notifierConfiguration.getSecurityDisabled());
        executionOptions.setRoomName(notifierConfiguration.getRoomName());

        return executionOptions;
    }
}

==> payara-embedded-all-4.1.1.171.1-sources.jar: fish/payara/notification/xmpp/XmppNotifierConfigurationExecutionOptionsFactory.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2016 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.notification.xmpp;

import fish.payara.nucleus.notification.configuration.NotifierType;
import fish.payara.nucleus.notification.domain.NotifierConfigurationExecutionOptionsFactory;
import org.glassfish.api.StartupRunLevel;
import org.glassfish.hk2.runlevel.RunLevel;
import org.jvnet.hk2.annotations.Service;

import javax.annotation.PostConstruct;
import java.io.UnsupportedEncodingException;

/**
 * @author mertcaliskan
 */
@Service
@RunLevel(StartupRunLevel.VAL)
public class XmppNotifierConfigurationExecutionOptionsFactory
        extends NotifierConfigurationExecutionOptionsFactory<XmppNotifierConfiguration, XmppNotifierConfigurationExecutionOptions> {

    @PostConstruct
    void postConstruct() {
        registerExecutionOptions(NotifierType.XMPP, this);
    }

    @Override
    public XmppNotifierConfigurationExecutionOptions build(XmppNotifierConfiguration notifierConfiguration) throws UnsupportedEncodingException {
        XmppNotifierConfigurationExecutionOptions executionOptions = new XmppNotifierConfigurationExecutionOptions();
        executionOptions.setEnabled(Boolean.parseBoolean(notifierConfiguration.getEnabled()));

        executionOptions.setHost(notifierConfiguration.getHost());
        executionOptions.setPort(notifierConfiguration.getPort());
        executionOptions.setServiceName(notifierConfiguration.getServiceName());
        executionOptions.setUsername(notifierConfiguration.getUsername());
        executionOptions.setPassword(notifierConfiguration.getPassword());
        executionOptions.setSecurityDisabled(notifierConfiguration.getSecurityDisabled());
        executionOptions.setRoomId(notifierConfiguration.getRoomId());

        return executionOptions;
    }
}
